==> cellyzer-gui-0.0.7.tar.gz: cellyzer-gui-0.0.7/README.md <==
# CELLYZER GUI

**CELLYZER** is a python library for CDR(Call Detail Records) data analyzing. I majorly supports 3 type of datasets : Call, Message and Cell/Antenna

This library can be used to easily get user records, connections between users, get population/traffic details using call and cell data etc. Also cellyzer can be used to visualize the population, user home/work locations, user trip/route identification etc.

**CELLYZER GUI** can be used by even nun-coding people to interact with the library without writing a single line of code.



## Installation

The source code is currently hosted on Github at https://github.com/anjuchamantha/cellyzer---CDR-data-analyzer. 

Binary installers for the latest released version are available at the Python package index:

https://pypi.org/project/cellyzer/

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install cellyzer-gui.

```
pip install cellyzer-gui
```

or pip3

```
pip3 install cellyzer-gui
```



## Dependencies

**CELLYZER-GUI** has some dependencies for calculations and data visualization 

- ```
  "cellyzer >= 1.1.1",
  "dash == 1.10.0",
  "dash_admin_components == 0.1.4",
  "dash_bootstrap_components == 0.9.2",
  ```

## License

The MIT License (MIT)

Copyright (c) 2020 Team Cellyzer

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.



## Documentation

The official documentation is hosted on https://github.com/anjuchamantha/cellyzer---CDR-data-analyzer. It includes a demo, a detailed reference for all functions, and guides on how to use **CELLYZER**.

==> cellyzer-gui-0.1.1.tar.gz: cellyzer-gui-0.1.1/README.md <==
# CELLYZER GUI

**CELLYZER** is a python library for CDR(Call Detail Records) data analyzing. I majorly supports 3 type of datasets : Call, Message and Cell/Antenna

This library can be used to easily get user records, connections between users, get population/traffic details using call and cell data etc. Also cellyzer can be used to visualize the population, user home/work locations, user trip/route identification etc.

**CELLYZER GUI** can be used by even nun-coding people to interact with the library without writing a single line of code.



## Installation

The source code is currently hosted on Github at https://github.com/anjuchamantha/cellyzer---CDR-data-analyzer. 

Binary installers for the latest released version are available at the Python package index:

https://pypi.org/project/cellyzer/

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install cellyzer-gui.

```
pip install cellyzer-gui
```

or pip3

```
pip3 install cellyzer-gui
```



## Dependencies

**CELLYZER-GUI** has some dependencies for calculations and data visualization 

- ```
  "cellyzer >= 1.1.1",
  "dash == 1.10.0",
  "dash_admin_components == 0.1.4",
  "dash_bootstrap_components == 0.9.2",
  ```

## License

The MIT License (MIT)

Copyright (c) 2020 Team Cellyzer

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.



## Documentation

The official documentation is hosted on https://anjuchamantha.github.io/cellyzer---CDR-data-analyzer/. It includes a demo, a detailed reference for all functions, and guides on how to use **CELLYZER**.
